@@ -91,6 +91,7 @@ KIpMsgEvent::RecieveAfter( RecievedMessage& msg ){
 		}
 		hiddenMessages.push_back( msg );
 	}
+	kipmsgWidget::playSound();
 	return true;
 }
 
@@ -104,6 +105,29 @@ KIpMsgEvent::SendAfter( SentMessage& msg ){
 	KIpMessengerLogger::GetInstance()->PutSentMessage( msg );
 }
 
+/**
+ * メッセージ暗号化失敗イベント。
+ * @retval true:暗号化せずに送信する
+ * @retval false:失敗させる
+ */
+void
+KIpMsgEvent::NotifySendEncryptionFail( HostListItem& host ){
+	KMessageBox::sorry( 0, QString( tr2i18n("Can't encryption message.\nMessage was not sent.") ) );
+}
+
+/**
+ * メッセージ暗号化失敗イベント。
+ * @retval true:暗号化せずに送信する
+ * @retval false:失敗させる
+ */
+bool
+KIpMsgEvent::IsSendContinueOnEncryptionFail( HostListItem& host ){
+	if ( KMessageBox::warningContinueCancel( 0, QString( tr2i18n("Can't encryption message.\nIs it send as plain text message?") ) ) == KMessageBox::Continue ){
+		return true;
+	}
+	return false;
+}
+
 /**
  * 送信リトライエラーイベント
  * ・特にすること無し。
@@ -540,7 +564,7 @@ KIpMsgEvent::ShowRecieveMsg( RecievedMessage& msg ){
 	}
 	KWin::activateWindow( recv->winId() );
 	recieveDialogs.append( recv );
-	kipmsgWidget::playSound();
+//	kipmsgWidget::playSound();
 }
 
 /**
